'use client'

import { useState, useRef, useEffect } from 'react'
import { FiSave, FiImage, FiX } from 'react-icons/fi'
import DashboardLayout from '../../../../../components/layout/DashboardLayout'
import { useUser } from '@/contexts/UserContext'
import { useParams, useRouter } from 'next/navigation'
import { categoryService, productService } from '@/services/api'
import Modal from '@/components/ui/Modal'

export default function EditProductPage() {
  const params = useParams()
  const id = params?.id as string
  const [formData, setFormData] = useState({
    name: '',
    price: '',
    category_id: '',
    description: '',
    kitchen_print: false
  })
  const [image, setImage] = useState<{ file?: File; preview?: string } | null>(null)
  const fileInputRef = useRef<HTMLInputElement>(null)
  const { user } = useUser()
  const router = useRouter()
  const [categories, setCategories] = useState<any[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState(false)
  const [success, setSuccess] = useState(false)

  const fetchProduct = async () => {
    try {
      const response = await productService.show(id, user?.token || '')
      setFormData({
        name: response.data.product.name,
        price: response.data.product.price,
        category_id: response.data.product.category_id,
        description: response.data.product.description || '',
        kitchen_print: Boolean(response.data.product.kitchen_print)
      })
      setImage({ preview: response.data.product.image })
      setLoading(false)
    } catch (err) {
      setError(true)
      setLoading(false)
    }
  }

  const fetchCategories = async () => {
    try {
      const response = await categoryService.index(user?.token || '')
      setCategories(response.data.categories)
    } catch (err) {
      setError(true)
    }
  }
  const handleInputChange = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement | HTMLSelectElement>) => {
    const { name, value } = e.target
    setFormData(prev => ({
      ...prev,
      [name]: value
    }))
  }

  const handleImageChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const file = e.target.files?.[0]
    if (file) {
      const preview = URL.createObjectURL(file)
      setImage({ file, preview })
    }
  }

  const removeImage = () => {
    if (image?.preview) {
      URL.revokeObjectURL(image.preview)
    }
    setImage(null)
    if (fileInputRef.current) {
      fileInputRef.current.value = ''
    }
  }

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    const formDataToSubmit = new FormData()
    formDataToSubmit.append('name', formData.name)
    formDataToSubmit.append('price', formData.price)
    formDataToSubmit.append('category_id', formData.category_id)
    formDataToSubmit.append('description', formData.description)
    formDataToSubmit.append('kitchen_print', formData.kitchen_print ? '1' : '0')

    if (image?.file) {
      formDataToSubmit.append('image', image.file)
    }

    try {
      await productService.update(id, formDataToSubmit, user?.token || '')
      setSuccess(true)
      setTimeout(() => {
        router.push('/dashboard/products')
      }, 1500)
    } catch (err) {
      setError(true)
    }
  }

  useEffect(() => {
    if (user?.token) {
      fetchProduct()
      fetchCategories()
    }
  }, [user?.token])



  return (
    <DashboardLayout>
      <div className="w-full mx-auto">
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg 
                     border border-slate-200/50 dark:border-slate-700/50">
          <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
            <h2 className="text-xl font-bold text-slate-800 dark:text-white">
              Ürün Düzenle
            </h2>
            <p className="text-sm text-slate-500 dark:text-slate-400 mt-1">
              Ürün bilgilerini güncellemek için formu kullanın
            </p>
          </div>

          <form onSubmit={handleSubmit} className="p-6 space-y-6">
            <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
              {/* Ürün Adı */}
              <div>
                <label htmlFor="name" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Ürün Adı
                </label>
                <input
                  id="name"
                  name="name"
                  type="text"
                  value={formData.name}
                  onChange={handleInputChange}
                  className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                           bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                           text-slate-800 dark:text-white
                           focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                           transition-all"
                  required
                />
              </div>

              {/* Fiyat */}
              <div>
                <label htmlFor="price" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Fiyat
                </label>
                <div className="relative">
                  <span className="absolute left-4 top-1/2 -translate-y-1/2 text-slate-400">₺</span>
                  <input
                    id="price"
                    name="price"
                    type="number"
                    step="0.01"
                    min="0"
                    value={formData.price}
                    onChange={handleInputChange}
                    className="w-full pl-8 pr-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                             bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                             text-slate-800 dark:text-white
                             focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                             transition-all"
                    required
                  />
                </div>
              </div>

              {/* Kategori */}
              <div>
                <label htmlFor="category_id" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Kategori
                </label>
                <select
                  id="category_id"
                  name="category_id"
                  value={formData.category_id}
                  onChange={handleInputChange}
                  className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                           bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                           text-slate-800 dark:text-white
                           focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                           transition-all"
                  required
                >
                  <option value="">Kategori Seçin</option>
                  {categories.map(category => (
                    <option key={category.id} value={category.id}>
                      {category.name}
                    </option>
                  ))}
                </select>
              </div>

              {/* Resim Yükleme */}
              <div>
                <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Ürün Görseli
                </label>
                <div className="relative">
                  {image ? (
                    <div className="relative w-full h-32 rounded-xl overflow-hidden group">
                      {/* eslint-disable-next-line @next/next/no-img-element */}
                      <img
                        src={image.file
                          ? URL.createObjectURL(image.file)
                          : `${process.env.NEXT_PUBLIC_API_URL_STORAGE}/${image.preview}`
                        }
                        alt=""
                        className="w-full h-full object-cover"
                      />
                      <div className="absolute inset-0 bg-black/40 opacity-0 group-hover:opacity-100 transition-opacity flex items-center justify-center gap-2">
                        <button
                          type="button"
                          onClick={removeImage}
                          className="p-2 rounded-lg bg-red-500 text-white hover:bg-red-600 transition-colors"
                        >
                          <FiX className="w-5 h-5" />
                        </button>
                      </div>
                    </div>
                  ) : (
                    <label className="flex flex-col items-center justify-center w-full h-32 rounded-xl border-2 border-dashed border-slate-200 dark:border-slate-700 hover:border-fuchsia-500 dark:hover:border-fuchsia-500 transition-colors cursor-pointer">
                      <FiImage className="w-8 h-8 text-slate-400" />
                      <span className="mt-2 text-sm text-slate-500">Görsel Seç veya Sürükle Bırak</span>
                      <input
                        type="file"
                        className="hidden"
                        name="image"
                        accept="image/*"
                        onChange={handleImageChange}
                        ref={fileInputRef}
                      />
                    </label>
                  )}
                </div>
              </div>
            </div>

            {/* Mutfak Yazdırma Seçeneği */}
            <div className="col-span-full">
              <div className="flex items-center gap-2">
                <input
                  type="checkbox"
                  id="kitchen_print"
                  name="kitchen_print"
                  checked={formData.kitchen_print}
                  onChange={(e) => setFormData(prev => ({
                    ...prev,
                    kitchen_print: e.target.checked
                  }))}
                  className="w-4 h-4 text-fuchsia-500 border-slate-300 dark:border-slate-600 
                           rounded focus:ring-fuchsia-500/50"
                />
                <label 
                  htmlFor="kitchen_print" 
                  className="text-sm font-medium text-slate-700 dark:text-slate-300"
                >
                  Mutfağa Gönder
                </label>
                <span className="text-xs text-slate-500 dark:text-slate-400">
                  (Bu ürün mutfak yazıcısına gönderilecek)
                </span>
              </div>
            </div>

            {/* İçindekiler */}
            <div>
              <label htmlFor="description" className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                İçindekiler
              </label>
              <textarea
                id="description"
                name="description"
                value={formData.description}
                onChange={handleInputChange}
                rows={4}
                className="w-full px-4 py-2.5 rounded-xl border border-slate-200/50 dark:border-slate-700/50 
                         bg-white/50 dark:bg-slate-700/50 backdrop-blur-sm
                         text-slate-800 dark:text-white
                         focus:outline-none focus:ring-2 focus:ring-fuchsia-500/50
                         transition-all"
              />
            </div>

            {/* Kaydet Butonu */}
            <div className="flex justify-end">
              <button
                type="submit"
                className="px-6 py-2.5 text-sm font-medium text-white
                       bg-gradient-to-r from-fuchsia-500 to-purple-600
                       rounded-xl hover:opacity-90 transition-all
                       flex items-center gap-2"
              >
                <FiSave className="w-4 h-4" />
                Değişiklikleri Kaydet
              </button>
            </div>
          </form>
        </div>
      </div>
      <Modal
        isOpen={success}
        onClose={() => setSuccess(false)}
        title="Başarılı"
        message="Ürün başarıyla güncellendi!"
      />
      <Modal
        isOpen={error}
        onClose={() => setError(false)}
        title="Hata"
        message="Ürün güncellenirken bir hata oluştu!"
      />
    </DashboardLayout>
  )
} 